# DomPHPTests
_The PHP unit tests made by Dom_

## Abstract
The need of unit test is a base of the software development. DomPHPTests allow
to test your programs based on directives.
Compared to others unit tests, it allow to parrallelize the tests to multiple 
processes. The tests are quicker.

## Configuration
Here are the options available to the command line :
    -h / --help : This help message
    --bootstrap : Load a PHP file before applying the tests
    --color :     Color the result for terminal view
    --debug :     Debug the DomPHPTests application
    --nofork :    Do not parrallelize the tests, use sequential mode
    --time :      Add the time for each test (in debug only)
Finish by the file(s) test to run.

If you prefer, you can also create a _domphptests.ini_ file containing the
options to use. Here an example :
    time = true
    color = true
    bootstrap = "Tests/autoload.php.dist"
    testfiles[] = "Tests/*Test.php"

The bootstrap is a PHP file which is loaded before starting the first test. It
can be used to add the autoloader by example.
    <?php
    spl_autoload_register();

## Unit tests
The unit tests are written with the formal form :
    <?php
    class TestClass extends DomPHPTests
    {
      public function testFirst ()
      {
        $obj = new object ();
        $res = $obj->method ();
        $this->assertSame ($res, "Should be returned by method");
      }
    }

In this example, the test _testFirst_ is run. It create a new object and apply
on it the method _method_. The result of the method is compared with the wanted
string "Should be returned by method". If the result is equal to the wanted
string, the test is validated. If the method return something else, the test is
failed.

Here are the allowed test methods :
- _$this->assertFalse ($condition, $message = "%s === false")_  
The test is valid if the condition is false.
You can change the message.
- _$this->assertGreaterThan ($val1, $val2, $message = "%s > %s")_  
The test is valid if $val1 > $val2.  
You can change the message.
- _$this->assertGreaterThanOrEqual ($val1, $val2, $message = "%s >= %s")_  
The test is valid if $val1 >= $val2.  
You can change the message.
- _$this->assertLessThan ($val1, $val2, $message = "%s < %s")_  
The test is valid if $val1 < $val2.  
You can change the message.
-_ $this->assertLessThanOrEqual ($val1, $val2, $message = "%s <= %s")_  
The test is valid if $val1 <= $val2.  
You can change the message.
- _$this->assertSame ($val1, $val2, $message = "%s === %s")_  
The test is valid if $val1 === $val2.  
You can change the message.
- _$this->assertTrue ($condition, $message = "%s === true")_  
The test is valid if $condition === true.  
You can change the message.
- _$this->expectOutputRegex ($expectedRegex)_  
The test is valid if the screen output match the regex.  
- _$this->expectOutputString ($expectedString)_  
The test is valid if the screen output is the same as the $expectedString.  
- _$this->expectException ($class = null, $message = null, $code = null)_  
The test is valid if an exception is raised. If the $class is set, the class
exception must be equal. If the $message is set, the exception message is
compared too. If the $code is set, the exception code is compared too.  
Attention to define the _expectException_ line BEFORE calling the method which
will generate the exception !

## Parrallelism
As the tests are runned simultaneously by test file, your tests must not use the
same file in the filesystem. It can be overwrite by another test at any time.
So you need to construct your tests to use temporary files or different filename
by test file.
